==> zhongyan-activity-service-api-1.0.3-20211202.090937-111-sources.jar: cn/com/duiba/zhongyan/activity/service/api/param/AnswerPageParam.java <==
package cn.com.duiba.zhongyan.activity.service.api.param;

import java.util.List;

/**
 * @author LuHui
 * @description 提交答卷参数
 *              整个类作为json字段存入答卷表
 * @date 2021/11/26  12:02
 */
public class AnswerPageParam {

    /**
     * 开始答题id
     */
    private Long startId;
    /**
     * 主题色
     */
    private String subjectColor;
    /**
     * 答题背景图
     */
    private String answerBackgroundImage;

    /**
     * 单按钮背景图
     */
    private String singleButtonBackground;

    /**
     * 单按钮文案颜色
     */
    private String singleButtonTextColor;

    /**
     * 主按钮背景图
     */
    private String primaryButtonBackground;

    /**
     * 主按钮文案颜色
     */
    private String primaryButtonTextColor;

    /**
     * 副按钮背景图
     */
    private String deputyButtonBackground;

    /**
     * 副按钮文案颜色
     */
    private String deputyButtonTextColor;

    /**
     * 活动标题
     */
    private String activityTitle;

    /**
     * 答案
     */
    private List<QuestionAnswerParam> questionList;


    public Long getStartId() {
        return startId;
    }

    public void setStartId(Long startId) {
        this.startId = startId;
    }

    public String getSubjectColor() {
        return subjectColor;
    }

    public void setSubjectColor(String subjectColor) {
        this.subjectColor = subjectColor;
    }

    public String getAnswerBackgroundImage() {
        return answerBackgroundImage;
    }

    public void setAnswerBackgroundImage(String answerBackgroundImage) {
        this.answerBackgroundImage = answerBackgroundImage;
    }

    public String getSingleButtonBackground() {
        return singleButtonBackground;
    }

    public void setSingleButtonBackground(String singleButtonBackground) {
        this.singleButtonBackground = singleButtonBackground;
    }

    public String getSingleButtonTextColor() {
        return singleButtonTextColor;
    }

    public void setSingleButtonTextColor(String singleButtonTextColor) {
        this.singleButtonTextColor = singleButtonTextColor;
    }

    public String getPrimaryButtonBackground() {
        return primaryButtonBackground;
    }

    public void setPrimaryButtonBackground(String primaryButtonBackground) {
        this.primaryButtonBackground = primaryButtonBackground;
    }

    public String getPrimaryButtonTextColor() {
        return primaryButtonTextColor;
    }

    public void setPrimaryButtonTextColor(String primaryButtonTextColor) {
        this.primaryButtonTextColor = primaryButtonTextColor;
    }

    public String getDeputyButtonBackground() {
        return deputyButtonBackground;
    }

    public void setDeputyButtonBackground(String deputyButtonBackground) {
        this.deputyButtonBackground = deputyButtonBackground;
    }

    public String getDeputyButtonTextColor() {
        return deputyButtonTextColor;
    }

    public void setDeputyButtonTextColor(String deputyButtonTextColor) {
        this.deputyButtonTextColor = deputyButtonTextColor;
    }

    public String getActivityTitle() {
        return activityTitle;
    }

    public void setActivityTitle(String activityTitle) {
        this.activityTitle = activityTitle;
    }

    public List<QuestionAnswerParam> getQuestionList() {
        return questionList;
    }

    public void setQuestionList(List<QuestionAnswerParam> questionList) {
        this.questionList = questionList;
    }
}

==> zhongyan-activity-service-api-1.0.16-1-sources.jar: cn/com/duiba/zhongyan/activity/service/api/param/AnswerPageParam.java <==
package cn.com.duiba.zhongyan.activity.service.api.param;

import java.io.Serializable;
import java.util.List;

/**
 * @author LuHui
 * @description 提交答卷参数
 *              整个类作为json字段存入答卷表
 * @date 2021/11/26  12:02
 */
public class AnswerPageParam implements Serializable {

    private static final long serialVersionUID = 2376583288583584196L;
    /**
     * 开始答题id
     */
    private Long startId;
    /**
     * 主题色
     */
    private String subjectColor;
    /**
     * 答题背景图
     */
    private String answerBackgroundImage;

    /**
     * 单按钮背景图
     */
    private String singleButtonBackground;

    /**
     * 单按钮文案颜色
     */
    private String singleButtonTextColor;

    /**
     * 主按钮背景图
     */
    private String primaryButtonBackground;

    /**
     * 主按钮文案颜色
     */
    private String primaryButtonTextColor;

    /**
     * 副按钮背景图
     */
    private String deputyButtonBackground;

    /**
     * 副按钮文案颜色
     */
    private String deputyButtonTextColor;

    /**
     * 活动标题
     */
    private String activityTitle;

    /**
     * 答案
     */
    private List<QuestionAnswerParam> questionList;


    public Long getStartId() {
        return startId;
    }

    public void setStartId(Long startId) {
        this.startId = startId;
    }

    public String getSubjectColor() {
        return subjectColor;
    }

    public void setSubjectColor(String subjectColor) {
        this.subjectColor = subjectColor;
    }

    public String getAnswerBackgroundImage() {
        return answerBackgroundImage;
    }

    public void setAnswerBackgroundImage(String answerBackgroundImage) {
        this.answerBackgroundImage = answerBackgroundImage;
    }

    public String getSingleButtonBackground() {
        return singleButtonBackground;
    }

    public void setSingleButtonBackground(String singleButtonBackground) {
        this.singleButtonBackground = singleButtonBackground;
    }

    public String getSingleButtonTextColor() {
        return singleButtonTextColor;
    }

    public void setSingleButtonTextColor(String singleButtonTextColor) {
        this.singleButtonTextColor = singleButtonTextColor;
    }

    public String getPrimaryButtonBackground() {
        return primaryButtonBackground;
    }

    public void setPrimaryButtonBackground(String primaryButtonBackground) {
        this.primaryButtonBackground = primaryButtonBackground;
    }

    public String getPrimaryButtonTextColor() {
        return primaryButtonTextColor;
    }

    public void setPrimaryButtonTextColor(String primaryButtonTextColor) {
        this.primaryButtonTextColor = primaryButtonTextColor;
    }

    public String getDeputyButtonBackground() {
        return deputyButtonBackground;
    }

    public void setDeputyButtonBackground(String deputyButtonBackground) {
        this.deputyButtonBackground = deputyButtonBackground;
    }

    public String getDeputyButtonTextColor() {
        return deputyButtonTextColor;
    }

    public void setDeputyButtonTextColor(String deputyButtonTextColor) {
        this.deputyButtonTextColor = deputyButtonTextColor;
    }

    public String getActivityTitle() {
        return activityTitle;
    }

    public void setActivityTitle(String activityTitle) {
        this.activityTitle = activityTitle;
    }

    public List<QuestionAnswerParam> getQuestionList() {
        return questionList;
    }

    public void setQuestionList(List<QuestionAnswerParam> questionList) {
        this.questionList = questionList;
    }
}
